<img align="right" width="180" height="180" src="https://raw.githubusercontent.com/zellerlab/GECCO/v0.6.2/static/gecco-square.png">

# Hi, I'm GECCO! [![Stars](https://img.shields.io/github/stars/zellerlab/GECCO.svg?style=social&maxAge=3600&label=Star)](https://github.com/zellerlab/GECCO/stargazers)

GECCO (Gene Cluster prediction with Conditional Random Fields) is a fast and
scalable method for identifying putative novel Biosynthetic Gene Clusters (BGCs)
in genomic and metagenomic data using Conditional Random Fields (CRFs).

**🚨 The `gecco-tool` package has been renamed to `gecco` starting from `v0.10.0`**

Please update your code and dependencies to use the new package name. This repository will only offer releases prior 
to `v0.10` for reproducibility. See the new PyPI page for the up-to-date versions of the package: 
[https://pypi.org/project/gecco/](https://pypi.org/project/gecco/)
